import unittest
from AcdhArcheAssets.uri_norm_rules import get_rules, get_normalized_uri

SAMPLES = [
    [
        "http://sws.geonames.org/1232324343/linz.html",
        "https://www.geonames.org/1232324343"
    ],
    [
        "http://d-nb.info/gnd/4074255-6/",
        "https://d-nb.info/gnd/4074255-6"
    ],
    [
        "https://d-nb.info/gnd/4074255-6",
        "https://d-nb.info/gnd/4074255-6"
    ]
]


class TestNormalizer(unittest.TestCase):
    def test__001_load_list(self):
        rules = get_rules()
        self.assertEqual(type(rules), list, "should be type 'list' ")

    def test__002_test_patterns(self):
        for x in SAMPLES:
            new_uri = get_normalized_uri(x[0])
            self.assertEqual(x[1], new_uri)



import json
import pkg_resources


def get_formats():
    """ returns a list dicts providing info about file formats and mime types

    :return: list dicts providing info about file formats and mime types
    :rtype: list

    """
    return json.loads(pkg_resources.resource_string(__name__, 'formats.json'))


def get_by_mtype(mtype):
    """ returns a list of mapping dicts for the provided mime type
    :param mtype: A mime type
    :type mtype: str

    :return: list of mapping dicts for the provided mime type
    :rtype: list

    """

    formats = get_formats()
    matches = [x for x in formats if mtype in x['MIME_type']]
    return matches


def get_by_extension(extension):
    """ returns a list of mapping dicts for the provided extension
    :param extension: A extension
    :type extension: str

    :return: list of mapping dicts for the provided extension
    :rtype: list

    """

    formats = get_formats()
    matches = [x for x in formats if extension in x['extensions']]
    return matches



import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="acdh_arche-assets",
    version="3.4.0",
    author="Mateusz Żółtak",
    author_email="mzoltak@oeaw.ac.at",
    description="A set of static assets used (mainly) for ARCHE data preprocessing",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/acdh-oeaw/arche-assets",
    packages=setuptools.find_packages(),
    package_data={'AcdhArcheAssets': ['uriNormRules.json', 'formats.json']},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True
)



import json
import pkg_resources
import re


def get_rules():
    """ returns a list of regex pattern matches

    :return: a list of regex patterns to normalize Authority IDs
    :rtype: list

    """
    return json.loads(pkg_resources.resource_string(__name__, 'uriNormRules.json'))


def get_normalized_uri(uri):
    """ takes a normdata uri and returns a normlalized version
    :param uri: A normdata uri
    :param type: str

    :return: The normalized URI
    :rtype: str
    """
    for x in get_rules():
        uri = re.sub(x['match'], x['replace'], uri)
    return uri
